@@ -1,6 +1,7 @@
 from django.db import models
 from django.utils import timezone
 from xj_user.models import Platform, BaseInfo
+from xj_thread.models import Thread
 import time
 
 
@@ -111,6 +112,7 @@ class Transact(models.Model):
     balance = models.DecimalField(verbose_name='余额', max_digits=32, decimal_places=8, db_index=True, default=0)
     pay_mode = models.ForeignKey(verbose_name='支付方式', to=PayMode, db_column='pay_mode_id', on_delete=models.DO_NOTHING,
                                  unique=False, blank=True, null=True, default=5)
+    thread_id = models.BigIntegerField(verbose_name='资金id', blank=True, null=True,)
     goods_info = models.JSONField(verbose_name='商品信息', blank=True, null=True)
     pay_info = models.JSONField(verbose_name='付款信息', blank=True, null=True)
     remark = models.TextField(verbose_name='备注', blank=True, null=True)
@@ -118,9 +120,10 @@ class Transact(models.Model):
     sand_box = models.ForeignKey(verbose_name='沙盒', to=SandBox, db_column='sand_box_id', related_name='+',
                                  on_delete=models.DO_NOTHING, unique=False, blank=True, null=True, db_index=True)
     finance_status_code = models.IntegerField(verbose_name='资金状态码', default='')
-    is_reverse = models.BooleanField(verbose_name='是否红冲', max_length=255, blank=True, null=True)
-    is_delete = models.BooleanField(verbose_name='是否删除', max_length=255, blank=True, null=True)
+    is_reverse = models.BooleanField(verbose_name='是否红冲', blank=True, null=True)
+    is_delete = models.BooleanField(verbose_name='是否删除', blank=True, null=True)
     is_write_off = models.BooleanField(verbose_name='是否核销', max_length=255, blank=True, null=True)
+    sand_box_status_code = models.CharField(verbose_name='沙盒状态码', max_length=32, blank=True, null=True)
 
     class Meta:
         db_table = 'finance_transact'
