@@ -7,6 +7,7 @@ from django.db.models import F
 from django.forms import model_to_dict
 from xj_user.services.user_platform_service import UserPlatformService
 from ..models import *
+from ..models import StatusCode
 
 from decimal import Decimal
 from ..utils.custom_tool import format_params_handle
@@ -36,7 +37,8 @@ class FinanceService:
                 # print('check_balance: platform不存在', platform, platform_info)
                 return {'err': 7002, 'msg': 'check_balance: platform不存在' + str(platform)}
             platform_id = platform_info.get('platform_id')
-
+        elif platform_id:
+            platform_id = platform_id
         currency_set = Currency.objects.filter(currency=currency).first()
         if not currency_set:
             # print('check_balance: currency不存在', currency, currency_set)
@@ -101,10 +103,13 @@ class FinanceService:
         else:
             transact_set_new = transact_set_new.filter(Q(sand_box__sand_box_name=sand_box))
         transact_set_new = transact_set_new.order_by('-transact_time').first()
-        transact_set_new = model_to_dict(transact_set_new)
         if transact_set_new:
+            transact_set_new = model_to_dict(transact_set_new)
             return {"balance": transact_set_new['balance']}
-        return True
+
+        return {"balance": 0}
+
+        # return True
 
     # 生成交易号：2位数（当前年份后2位数字）+8位数（当前时间戳去头2位）+6位数（用户名 经过hash crc16生成的 4位十六进制 转成5位数 然后头为补0）
     @staticmethod
@@ -163,6 +168,14 @@ class FinanceService:
                 return {'err': 3001, 'msg': 'platform不存在', }
             query_dict['platform_id'] = platform_set['platform_id']
 
+        finance_status_code = params.get('finance_status_code', '')
+        if finance_status_code:
+            sand_box_set = StatusCode.objects.filter(finance_status_code=finance_status_code).first().id
+            # print("1",sand_box_set)
+            if not sand_box_set:
+                return {'err': 3001, 'msg': 'finance_status_code不存在', }
+            query_dict['finance_status_code'] = sand_box_set
+
         # 搜索币种
         currency = params.get('currency', '')
         if currency:
@@ -284,4 +297,3 @@ class FinanceService:
     #     transacts = transacts.order_by('-transact_time')
     #
     #     return {'err': 0, 'msg': 'OK', 'query_set': transacts, }
-
