@@ -38,7 +38,7 @@ class FinanceTransactSerializer(serializers.ModelSerializer):
     sand_box = serializers.SerializerMethodField()
     transact_time = serializers.SerializerMethodField()
     transact_timestamp = serializers.SerializerMethodField()
-    # finance_status_code = serializers.SerializerMethodField()
+    # sand_box_type_status = serializers.SerializerMethodField()
 
     # 自定义外键字段
     # platform = serializers.ReadOnlyField(source='platform.platform_name')
@@ -59,6 +59,7 @@ class FinanceTransactSerializer(serializers.ModelSerializer):
         fields = [
             'id',
             'transact_no',
+            'thread_id',
             'transact_time',
             'transact_timestamp',
             'account_id',
@@ -82,7 +83,8 @@ class FinanceTransactSerializer(serializers.ModelSerializer):
             'sand_box',
             'goods_info',
             'pay_info',
-            'finance_status_code'
+            'finance_status_code',
+            'sand_box_status_code'
         ]
 
     def get_lend(self, obj):
@@ -140,7 +142,7 @@ class FinanceTransactService:
             return None, '记录不存在'
 
         serializer = FinanceTransactSerializer(transact, many=False)
-        # print(">>> serializer:", serializer)
+        print(">>> serializer:", serializer)
 
         # # 翻译
         # output = _("Welcome to my site.")
@@ -149,6 +151,7 @@ class FinanceTransactService:
 
         # POST方法，如果无transact_no则是新增，否则为修改
 
+
     @staticmethod
     def finance_transact_detailed(transact_no):
         transact = Transact.objects.filter(transact_no=transact_no).first()
@@ -220,8 +223,8 @@ class FinanceTransactService:
             if not item['their_account']:
                 return None, '用户their_account_id不存在'
         # 边界检查，自己不能和自己交易
-        if account_id == their_account_id:
-            return None, '自己不能和自己交易'
+        # if account_id == their_account_id:
+        #     return None, '自己不能和自己交易'
 
         # 生成发起交易的用户名 todo 要不用金额会不会更安全？怎么处理重复的可能性
         username = item['account'].user_name
@@ -303,6 +306,10 @@ class FinanceTransactService:
         if param.get('finance_status_code', ''):
             item['finance_status_code'] = param.get('finance_status_code', '')
 
+        if param.get('sand_box_status_code', ""):
+            item['sand_box_status_code'] = param.get('sand_box_status_code',"")
+
+
         # 沙盒 ----------------------------------------------------------------------
         sand_box_name = param.get('sand_box', '')
         if is_create:
@@ -326,6 +333,11 @@ class FinanceTransactService:
             Q(transact_time__lt=item['transact_time']) &
             ~Q(transact_no=item['transact_no'])
         )
+
+        # 信息模块id
+        thread_id = param.get('thread_id', '')
+        item['thread_id'] = thread_id
+
         # 如果有沙盒。
         if item['sand_box']:
             balance_set = balance_set.filter(Q(sand_box_id=item['sand_box']))
@@ -443,6 +455,8 @@ class FinanceTransactService:
         serializer.validated_data['balance'] = item['balance']
         serializer.validated_data['transact_time'] = item['transact_time']
         serializer.validated_data['finance_status_code'] = item.get('finance_status_code', None)
+        serializer.validated_data['thread_id'] = item.get('thread_id', None)
+        serializer.validated_data['sand_box_status_code'] = item.get('sand_box_status_code', None)
 
         # print(">>> serializer.validated_data: ", serializer.validated_data,)
         # print(">>> serializer: ", serializer,)
@@ -484,6 +498,7 @@ class FinanceTransactService:
         update_serializer.validated_data['outgo'] = item['outgo']
         update_serializer.validated_data['balance'] = item['balance']
         update_serializer.validated_data['transact_time'] = item['transact_time']
+        # update_serializer.validated_data['sand_box_type_status'] = item.get('sand_box_type_status', None)
 
         update_serializer.save()
 
