@@ -1,7 +1,9 @@
+import json
 from decimal import Decimal
 import random
 
 import pytz
+from django.core.paginator import Paginator
 from django.db.models import Q
 from django.forms import model_to_dict
 from rest_framework import serializers
@@ -9,11 +11,19 @@ from pathlib import Path
 from main.settings import BASE_DIR
 from xj_enroll.utils.custom_tool import format_params_handle
 from xj_finance.services.finance_transact_service import FinanceTransactService
+from xj_thread.utils.join_list import JoinList
 from xj_user.models import BaseInfo
+from xj_user.services.user_platform_service import UserPlatformService
+from xj_thread.services.thread_list_service import ThreadListService
 from .finance_service import FinanceService
 from ..models import Transact
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
+from logging import getLogger
+import json as default_json
+from json.encoder import JSONEncoder
+
+logger = getLogger('log')
 
 module_root = str(Path(__file__).resolve().parent)
 # 配置之对象
@@ -22,6 +32,7 @@ module_config_dict = JDict(JConfig.get_section(path=str(BASE_DIR) + "/config.ini
 
 sand_box_meet = main_config_dict.sand_box_meet or module_config_dict.sand_box_meet or ""
 sand_box_receivable = main_config_dict.sand_box_receivable or module_config_dict.sand_box_receivable or ""
+sand_box_cash_withdrawal = main_config_dict.sand_box_cash_withdrawal or module_config_dict.sand_box_cash_withdrawal or ""
 
 
 # 声明用户序列化
@@ -68,6 +79,7 @@ class FinanceTransactsSerializer(serializers.ModelSerializer):
             'id',
             # 'transact_no',
             'transact_no',
+            "thread_id",
             'transact_time',
             # 'transact_timestamp',
             'platform_id',
@@ -95,7 +107,8 @@ class FinanceTransactsSerializer(serializers.ModelSerializer):
             'is_reverse',
             'is_delete',
             'is_write_off',
-            'finance_status_code'
+            'finance_status_code',
+            "sand_box_status_code"
         ]
 
     # def get_order(self, obj):
@@ -139,6 +152,10 @@ class FinanceTransactsService:
             return None, valid['msg']
         transacts = Transact.objects.filter(account_id=user_id).filter(**valid['query_dict'])
         transacts = transacts.order_by('-transact_time')
+        # print(params['transact_time_start'])
+        if params.get("transact_time_start", None) and params.get("transact_time_end", None):
+            transacts = transacts.filter(
+                transact_time__range=(params['transact_time_start'], params['transact_time_end']))
 
         print(">>> transacts: ", transacts)
 
@@ -173,7 +190,6 @@ class FinanceTransactsService:
             it['order'] = page * size + i + 1
             it['platform_name'] = params.get('platform', '')
             res_list.append(it)
-
         # return {'total': total, 'list': res_list, 'statistics': statistic_list}, None
 
         return {'size': int(size), 'page': int(page + 1), 'total': total, 'list': res_list}, None
@@ -189,15 +205,6 @@ class FinanceTransactsService:
         #     # 'data': output,
         # })
 
-    # 生成随机的4位数数字
-    @staticmethod
-    def random_four_int():
-        str = ""
-        for i in range(4):
-            ch = chr(random.randrange(ord('0'), ord('9') + 1))
-            str += ch
-        return str
-
     @staticmethod
     def detail(pk=None, order_no=None, transact_no=None, field_list=None):
         """
@@ -290,7 +297,7 @@ class FinanceTransactsService:
             meet_data['pay_mode_id'] = finance_transact_data['pay_mode_id']  # 支付方式
             meet_data['platform_id'] = finance_transact_data['platform_id']  # 所属平台
             meet_data['summary'] = finance_transact_data['summary']  # 摘要说明
-            meet_data['finance_status_code'] = 3  # 资金状态码
+            meet_data['finance_status_code'] = 2  # 资金状态码 finance_status_code 242 报名成功 待付款
 
             # 应付数据
             receivable_data['sand_box'] = sand_box_meet  # 沙盒应付
@@ -304,7 +311,7 @@ class FinanceTransactsService:
             receivable_data['pay_mode_id'] = finance_transact_data['pay_mode_id']  # 支付方式
             receivable_data['platform_id'] = finance_transact_data['platform_id']  # 所属平台
             receivable_data['summary'] = finance_transact_data['summary']  # 摘要说明
-            receivable_data['finance_status_code'] = 3  # 资金状态码
+            receivable_data['finance_status_code'] = 2  # 资金状态码  finance_status_code 242 报名成功 待付款
 
             # while True:
             #     number = ''.join(str(x) for x in random.sample(range(10), 3))
@@ -347,7 +354,8 @@ class FinanceTransactsService:
         for v in finance_transact_data:
             transact_no = v['transact_no']
             if type == "write_off":
-                v['transact_no'] = transact_no.rstrip(transact_no[-1]) + str(int(transact_no[-1])) + "-2"
+                # v['transact_no'] = transact_no.rstrip(transact_no[-1]) + str(int(transact_no[-1])) + "-2"
+                v['transact_no'] = FinanceService.make_unicode(str(transact_no))  # 流水号
                 finance_transact, post_err = FinanceTransactService.post(v)
                 if post_err:
                     return None, post_err
@@ -355,4 +363,86 @@ class FinanceTransactsService:
                 Transact.objects.filter(transact_no=transact_no).update(is_write_off=1, is_reverse=None)  # 沙盒核销
             elif type == "reverse":
                 Transact.objects.filter(transact_no=transact_no).update(is_reverse=1, is_write_off=None)  # 沙盒红冲
+            elif type == "cash_withdrawal":
+                v['transact_no'] = FinanceService.make_unicode(str(order_no))  # 流水号
+                finance_transact, post_err = FinanceTransactService.post(v)
+                if post_err:
+                    return None, post_err
+                    # 生成真实记录成功后 原沙盒记录改为核销 并把提现状态改成 已提现
+                Transact.objects.filter(transact_no=transact_no).update(is_write_off=1, sand_box_status_code="withdrew",
+                                                                        is_reverse=None)  # 沙盒核销
+
         return None, None
+
+    @staticmethod
+    def cash_withdrawal(params):
+        platform_set, err = UserPlatformService.payment_get_platform_info(params['platform_id'])
+        if err:
+            return None, err
+
+        balance = FinanceService.check_balance(account_id=params['user_id'], platform=platform_set['platform_name'],
+                                               # platform_id=None,
+                                               currency='CNY',
+                                               sand_box=None)
+        if balance['balance'] < float(params['total_amount']):
+            return None, "余额不足"
+        params['total_fee'] = float("-" + params['total_amount'])
+        params['pay_mode'] = 'BALANCE'
+
+        # （用户余额应扣）
+        finance_data = {
+            "sand_box": sand_box_cash_withdrawal,  # 提现沙盒
+            "order_no": FinanceService.make_unicode(str(params['user_id'])),
+            "transact_no": FinanceService.make_unicode(str(params['user_id'])),
+            "account_id": params['user_id'],
+            "their_account_id": params['user_id'],
+            "platform": platform_set['platform_name'],
+            "amount": params['total_fee'],
+            "currency": "CNY",
+            "pay_mode": params['pay_mode'],
+            "finance_status_code": 2,
+            "sand_box_status_code": "withdrawing",
+            "summary": "用户提现",
+
+        }
+
+        # # （平台应付）
+        # platform_revenue_data = {
+        #     "sand_box":sand_box_meet,
+        #     "order_no": FinanceService.make_unicode(str(params['user_id'])),
+        #     # their_account_name": sub_appid,
+        #     "account_id": finance_data['their_account'],
+        #     "their_account_id": params['user_id'],
+        #     "platform": params['platform'],
+        #     "amount": params['total_fee'],
+        #     "summary": "用户提现",
+        #     "currency": "CNY",
+        #     "pay_mode": "BALANCE",
+        #     "finance_status_code": 2
+        # }
+        finance_platform_data_set, finance_platform_err = FinanceTransactService.post(finance_data)
+        if finance_platform_err:
+            return None, finance_platform_err
+            print(">>>>payment_logic_processing_err", finance_platform_err)
+            logger.info(">>>>payment_logic_processing" + "写入资金模块失败（用户余额应扣）")
+        return None, None
+
+    @staticmethod
+    def get_finance_thread(params, user_id):
+        transact_list, err = FinanceTransactsService.get(params, user_id)
+        if err:
+            return None, err
+        # print("transact_list", transact_list)
+
+        thread_id_list = [item.get("thread_id", None) for item in transact_list['list']]
+        # print("thread_id_list:", thread_id_list)
+        thread_list, err = ThreadListService.search(thread_id_list)
+        if err:
+            return None, err
+        # print("thread_list:", thread_list)
+        data = JoinList(transact_list['list'], thread_list, "thread_id", "id").join()
+        # print("data:", data)
+        # print(thread_id_list)
+        # total = transact.count()
+        return {'total': 0, 'list': data}, None
+        # return {'size': int(size), 'page': int(page + 1), 'total': total, 'list': thread_id_list}, None
