@@ -18,6 +18,7 @@ from .apis.finance_status_code import FinanceStatusCode
 urlpatterns = [
     re_path(r'^transacts/?$', FinanceTransacts.as_view(), ),
     re_path(r'^transact/?$', FinanceTransact.as_view(), ),
+    re_path(r'^transacts_plus/?$', FinanceTransacts.get_finance_thread, ),
     re_path(r'^pay_mode/?$', FinancePayMode.as_view(), ),
     # re_path(r'^_pay/?$', FinancePay.as_view(), ),
     # re_path(r'^_pay_test/?$', FinanceTestPay.as_view(), ),
@@ -29,6 +30,7 @@ urlpatterns = [
     re_path(r'^balance/?$', FinanceBalance.as_view(), ),
     re_path(r'^distribution/?$', FinanceTransact.distribution, ),
     re_path(r'^write_off/?$', FinanceTransact.write_off, ),
+    re_path(r'^cash_withdrawal/?$', FinanceBalance.cash_withdrawal, ),
     re_path(r'^status_code/?$', FinanceStatusCode.as_view(), ),
 
     # 该功能已使用finance_transact的POST方法代替
